[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-59-g11e9605

2017-02-13 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  11e9605179e340833d95115fb0178d2ee84b3e24 (commit)
  from  38bfe65eba21c697d05e8bed79635fc125cdac17 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=11e9605179e340833d95115fb0178d2ee84b3e24
commit 11e9605179e340833d95115fb0178d2ee84b3e24
Author: Kitware Robot 
AuthorDate: Tue Feb 14 00:01:05 2017 -0500
Commit: Kitware Robot 
CommitDate: Tue Feb 14 00:01:05 2017 -0500

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index bb79b6d..8b1882f 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 8)
-set(CMake_VERSION_PATCH 20170213)
+set(CMake_VERSION_PATCH 20170214)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-117-gd358f8b

2017-02-13 Thread Daniel Pfeifer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  d358f8bba5418d0a8e95bd5efe0a913b8acb2a13 (commit)
   via  e0f3931226d6f947572bce7a4b98c55812bba105 (commit)
   via  72dcbbe5c017a4c071187259f9594ccf02f7b466 (commit)
   via  7fb14775a3cce73dc0cb0d759b96059a95f7104b (commit)
   via  615e2a17e499b2bd53cce8da1a0cfae36d67b24a (commit)
   via  45b49099d9dd034fd1e7344b3bae88b0e3d3427a (commit)
   via  5396bc92d0162fa9a9462e15ccaae8764da8ff98 (commit)
  from  d8aec3f2d5478ffb7235b638d33d08e944093916 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d358f8bba5418d0a8e95bd5efe0a913b8acb2a13
commit d358f8bba5418d0a8e95bd5efe0a913b8acb2a13
Merge: d8aec3f e0f3931
Author: Daniel Pfeifer 
AuthorDate: Mon Feb 13 17:29:12 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 17:29:12 2017 -0500

Merge topic 'command-cleanup' into next

e0f39312 cmCommands: add commands directly to cmState
72dcbbe5 split Default commands into Scripting and Project
7fb14775 cmDisallowedCommand: extract policy checking from cmCommand
615e2a17 cmCommand: Don't prefix error message with command name
45b49099 cmCommand: make noncopyable
5396bc92 cmCommand: remove member Helper


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e0f3931226d6f947572bce7a4b98c55812bba105
commit e0f3931226d6f947572bce7a4b98c55812bba105
Author: Daniel Pfeifer 
AuthorDate: Fri Jan 20 22:40:16 2017 +0100
Commit: Daniel Pfeifer 
CommitDate: Mon Feb 13 22:39:20 2017 +0100

cmCommands: add commands directly to cmState

diff --git a/Source/cmCommands.cxx b/Source/cmCommands.cxx
index 64cd12e..b58dc62 100644
--- a/Source/cmCommands.cxx
+++ b/Source/cmCommands.cxx
@@ -1,6 +1,7 @@
 /* Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
file Copyright.txt or https://cmake.org/licensing for details.  */
 #include "cmCommands.h"
+#include "cmState.h"
 
 #include "cmAddCustomCommandCommand.h"
 #include "cmAddCustomTargetCommand.h"
@@ -105,170 +106,162 @@
 #include "cmWriteFileCommand.h"
 #endif
 
-std::vector GetScriptingCommands()
+void GetScriptingCommands(cmState* state)
 {
-  std::vector commands;
+  state->AddCommand(new cmBreakCommand);
+  state->AddCommand(new cmCMakeMinimumRequired);
+  state->AddCommand(new cmCMakePolicyCommand);
+  state->AddCommand(new cmConfigureFileCommand);
+  state->AddCommand(new cmContinueCommand);
+  state->AddCommand(new cmExecProgramCommand);
+  state->AddCommand(new cmExecuteProcessCommand);
+  state->AddCommand(new cmFileCommand);
+  state->AddCommand(new cmFindFileCommand);
+  state->AddCommand(new cmFindLibraryCommand);
+  state->AddCommand(new cmFindPackageCommand);
+  state->AddCommand(new cmFindPathCommand);
+  state->AddCommand(new cmFindProgramCommand);
+  state->AddCommand(new cmForEachCommand);
+  state->AddCommand(new cmFunctionCommand);
+  state->AddCommand(new cmGetCMakePropertyCommand);
+  state->AddCommand(new cmGetDirectoryPropertyCommand);
+  state->AddCommand(new cmGetFilenameComponentCommand);
+  state->AddCommand(new cmGetPropertyCommand);
+  state->AddCommand(new cmIfCommand);
+  state->AddCommand(new cmIncludeCommand);
+  state->AddCommand(new cmListCommand);
+  state->AddCommand(new cmMacroCommand);
+  state->AddCommand(new cmMakeDirectoryCommand);
+  state->AddCommand(new cmMarkAsAdvancedCommand);
+  state->AddCommand(new cmMathCommand);
+  state->AddCommand(new cmMessageCommand);
+  state->AddCommand(new cmOptionCommand);
+  state->AddCommand(new cmParseArgumentsCommand);
+  state->AddCommand(new cmReturnCommand);
+  state->AddCommand(new cmSeparateArgumentsCommand);
+  state->AddCommand(new cmSetCommand);
+  state->AddCommand(new cmSetDirectoryPropertiesCommand);
+  state->AddCommand(new cmSetPropertyCommand);
+  state->AddCommand(new cmSiteNameCommand);
+  state->AddCommand(new cmStringCommand);
+  state->AddCommand(new cmUnsetCommand);
+  state->AddCommand(new cmWhileCommand);
 
-  commands.push_back(new cmBreakCommand);
-  commands.push_back(new cmCMakeMinimumRequired);
-  commands.push_back(new cmCMakePolicyCommand);
-  commands.push_back(new cmConfigureFileCommand);
-  commands.push_back(new cmContinueCommand);
-  commands.push_back(new cmExecProgramCommand);
-  commands.push_back(new cmExecuteProcessCommand);
-  commands.push_back(new cmFileCommand);
-  commands.push_back(new cmFindFileCommand);
-  commands.push_back(new cmFindLibraryCommand);
-  commands.push_back(new cmFindPackageCommand);
-  commands.push_back(new cmFindPathCommand);
-  commands.push_back(new cmFindProgramCommand);
-  commands.push_

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-110-gd8aec3f

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  d8aec3f2d5478ffb7235b638d33d08e944093916 (commit)
   via  07c3380a6e2a09b7e5976ddbacf385b8b4cde2cd (commit)
   via  4168bc184e3e15ee76485e49d3bc5852b90f27de (commit)
  from  f8c5b31f33becfba9f25ca29cc4caee6b343f93c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d8aec3f2d5478ffb7235b638d33d08e944093916
commit d8aec3f2d5478ffb7235b638d33d08e944093916
Merge: f8c5b31 07c3380
Author: Brad King 
AuthorDate: Mon Feb 13 14:02:33 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 14:02:33 2017 -0500

Merge topic 'execute_process-default-encoding' into next

07c3380a execute_process: Restore no-decoding default behavior
4168bc18 Help: Improve execute_process ENCODING option documentation


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=07c3380a6e2a09b7e5976ddbacf385b8b4cde2cd
commit 07c3380a6e2a09b7e5976ddbacf385b8b4cde2cd
Author: Brad King 
AuthorDate: Mon Feb 13 13:49:14 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 13:53:17 2017 -0500

execute_process: Restore no-decoding default behavior

Since commit v3.8.0-rc1~232^2 (execute_process: Add ENCODING option for
Windows child process output, 2016-11-23) we decode child process output
using the console's active codepage by default.  This differs from
previous versions of CMake and is therefore incompatible.  Changing this
default will require a policy, so for now revert the default behavior
back to performing no decoding.

Reported-by: Nils Gladitz 

diff --git a/Help/command/execute_process.rst b/Help/command/execute_process.rst
index 5a77735..d617243 100644
--- a/Help/command/execute_process.rst
+++ b/Help/command/execute_process.rst
@@ -75,10 +75,10 @@ Options:
  ``NONE``
Perform no decoding.  This assumes that the process output is encoded
in the same way as CMake's internal encoding (UTF-8).
+   This is the default.
  ``AUTO``
Use the current active console's codepage or if that isn't
available then use ANSI.
-   This is the default.
  ``ANSI``
Use the ANSI codepage.
  ``OEM``
diff --git a/Source/cmExecuteProcessCommand.cxx 
b/Source/cmExecuteProcessCommand.cxx
index eb26a50..92cdf64 100644
--- a/Source/cmExecuteProcessCommand.cxx
+++ b/Source/cmExecuteProcessCommand.cxx
@@ -47,7 +47,7 @@ bool 
cmExecuteProcessCommand::InitialPass(std::vector const& args,
   std::string error_variable;
   std::string result_variable;
   std::string working_directory;
-  cmProcessOutput::Encoding encoding = cmProcessOutput::Auto;
+  cmProcessOutput::Encoding encoding = cmProcessOutput::None;
   for (size_t i = 0; i < args.size(); ++i) {
 if (args[i] == "COMMAND") {
   doing_command = true;

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4168bc184e3e15ee76485e49d3bc5852b90f27de
commit 4168bc184e3e15ee76485e49d3bc5852b90f27de
Author: Brad King 
AuthorDate: Mon Feb 13 13:43:01 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 13:53:17 2017 -0500

Help: Improve execute_process ENCODING option documentation

Spell out the options in a definition list and document each one.

diff --git a/Help/command/execute_process.rst b/Help/command/execute_process.rst
index 71233d9..5a77735 100644
--- a/Help/command/execute_process.rst
+++ b/Help/command/execute_process.rst
@@ -70,10 +70,21 @@ Options:
 ``ENCODING ``
  On Windows, the encoding that is used to decode output from the process.
  Ignored on other platforms.
- Valid encoding names are: ``AUTO`` (the default), ``NONE``, ``UTF8``,
- ``ANSI`` and ``OEM``.
- ``AUTO`` encoding means current active console's codepage will be used
- or if that isn't available then ``ANSI`` codepage will be used.
+ Valid encoding names are:
+
+ ``NONE``
+   Perform no decoding.  This assumes that the process output is encoded
+   in the same way as CMake's internal encoding (UTF-8).
+ ``AUTO``
+   Use the current active console's codepage or if that isn't
+   available then use ANSI.
+   This is the default.
+ ``ANSI``
+   Use the ANSI codepage.
+ ``OEM``
+   Use the original equipment manufacturer (OEM) code page.
+ ``UTF8``
+   Use the UTF-8 codepage.
 
 If more than one ``OUTPUT_*`` or ``ERROR_*`` option is given for the
 same pipe the precedence is not specified.

---

Summary of changes:
 Help/command/execute_process.rst   |   19 +++
 Source/cmExecuteProcessCommand.cxx |2 +-
 2 files changed, 16 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-107-gf8c5b31

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  f8c5b31f33becfba9f25ca29cc4caee6b343f93c (commit)
   via  d5d8170f3628c867bd14f385de3d5b8b82f01109 (commit)
  from  6ddde7ce0264de27af6a5160695506abb52906e2 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f8c5b31f33becfba9f25ca29cc4caee6b343f93c
commit f8c5b31f33becfba9f25ca29cc4caee6b343f93c
Merge: 6ddde7c d5d8170
Author: Brad King 
AuthorDate: Mon Feb 13 13:20:22 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 13:20:22 2017 -0500

Merge topic 'command-cleanup' into next

d5d8170f Revert topic 'command-cleanup'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d5d8170f3628c867bd14f385de3d5b8b82f01109
commit d5d8170f3628c867bd14f385de3d5b8b82f01109
Author: Brad King 
AuthorDate: Mon Feb 13 13:19:59 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 13:19:59 2017 -0500

Revert topic 'command-cleanup'

It will be revised and restored.

diff --git a/Help/manual/cmake-commands.7.rst b/Help/manual/cmake-commands.7.rst
index 611c989..d0c2986 100644
--- a/Help/manual/cmake-commands.7.rst
+++ b/Help/manual/cmake-commands.7.rst
@@ -7,103 +7,91 @@ cmake-commands(7)
 
.. contents::
 
-Scripting Commands
-==
+Normal Commands
+===
 
-These commands are always available.
+These commands may be used freely in CMake projects.
 
 .. toctree::
:maxdepth: 1
 
+   /command/add_compile_options
+   /command/add_custom_command
+   /command/add_custom_target
+   /command/add_definitions
+   /command/add_dependencies
+   /command/add_executable
+   /command/add_library
+   /command/add_subdirectory
+   /command/add_test
+   /command/aux_source_directory
/command/break
+   /command/build_command
/command/cmake_host_system_information
/command/cmake_minimum_required
/command/cmake_parse_arguments
/command/cmake_policy
/command/configure_file
/command/continue
+   /command/create_test_sourcelist
+   /command/define_property
/command/elseif
/command/else
+   /command/enable_language
+   /command/enable_testing
/command/endforeach
/command/endfunction
/command/endif
/command/endmacro
/command/endwhile
/command/execute_process
+   /command/export
/command/file
/command/find_file
/command/find_library
/command/find_package
/command/find_path
/command/find_program
+   /command/fltk_wrap_ui
/command/foreach
/command/function
/command/get_cmake_property
/command/get_directory_property
/command/get_filename_component
/command/get_property
-   /command/if
-   /command/include
-   /command/list
-   /command/macro
-   /command/mark_as_advanced
-   /command/math
-   /command/message
-   /command/option
-   /command/return
-   /command/separate_arguments
-   /command/set_directory_properties
-   /command/set_property
-   /command/set
-   /command/site_name
-   /command/string
-   /command/unset
-   /command/variable_watch
-   /command/while
-
-Project Commands
-
-
-These commands are available only in CMake projects.
-
-.. toctree::
-   :maxdepth: 1
-
-   /command/add_compile_options
-   /command/add_custom_command
-   /command/add_custom_target
-   /command/add_definitions
-   /command/add_dependencies
-   /command/add_executable
-   /command/add_library
-   /command/add_subdirectory
-   /command/add_test
-   /command/aux_source_directory
-   /command/build_command
-   /command/create_test_sourcelist
-   /command/define_property
-   /command/enable_language
-   /command/enable_testing
-   /command/export
-   /command/fltk_wrap_ui
/command/get_source_file_property
/command/get_target_property
/command/get_test_property
+   /command/if
/command/include_directories
/command/include_external_msproject
/command/include_regular_expression
+   /command/include
/command/install
/command/link_directories
/command/link_libraries
+   /command/list
/command/load_cache
+   /command/macro
+   /command/mark_as_advanced
+   /command/math
+   /command/message
+   /command/option
/command/project
/command/qt_wrap_cpp
/command/qt_wrap_ui
/command/remove_definitions
+   /command/return
+   /command/separate_arguments
+   /command/set_directory_properties
+   /command/set_property
+   /command/set
/command/set_source_files_properties
/command/set_target_properties
/command/set_tests_properties
+   /command/site_name
/command/source_group
+   /command/string
/command/target_compile_definitions
/command/target_compile_fe

[Cmake-commits] CMake branch, release, updated. v3.8.0-rc1-4-g6cbad49

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, release has been updated
   via  6cbad490c2fdbd9bdc67b406b9f2dcdc21e08ddb (commit)
   via  30abf145fd48f50c26ee7553fd2512e59be97f25 (commit)
   via  97917900d146acd55a7e453f477c52cd2e816eb3 (commit)
   via  971384c28759ad042624bda3893be6fdb1795591 (commit)
  from  84df4a49500e51ac6e2a19a77e385e66234386f7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 Help/command/if.rst|6 +++---
 Help/manual/cmake-developer.7.rst  |4 ++--
 Help/manual/cmake-language.7.rst   |4 ++--
 Modules/CMakePackageConfigHelpers.cmake|6 +++---
 Utilities/Sphinx/apply_qthelp_css_workaround.cmake |   14 +-
 Utilities/Sphinx/cmake.py  |8 ++--
 6 files changed, 25 insertions(+), 17 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-105-g6ddde7c

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  6ddde7ce0264de27af6a5160695506abb52906e2 (commit)
   via  38bfe65eba21c697d05e8bed79635fc125cdac17 (commit)
   via  6cbad490c2fdbd9bdc67b406b9f2dcdc21e08ddb (commit)
  from  fb4044b6f07df33a146df4e19da65e415899cda7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6ddde7ce0264de27af6a5160695506abb52906e2
commit 6ddde7ce0264de27af6a5160695506abb52906e2
Merge: fb4044b 38bfe65
Author: Brad King 
AuthorDate: Mon Feb 13 11:46:16 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 11:46:16 2017 -0500

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-100-gc7a665b

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c7a665b6002f98abb4d48f270ef7127bc2306b5a (commit)
   via  7da1cde3aedd3f09dffaadbe5815a04aa71d411a (commit)
   via  0c4379353fb82e0d5223e82faeaf14f4dcc7a80b (commit)
   via  0cab748cf84a844df36623f03c5ed7b8065ceb5a (commit)
   via  26662fc3d38f93b5aaebdcb59d8937f9661020f9 (commit)
   via  6c8d65963104451b15aa331a6914173af42a224c (commit)
  from  e8d7474006657657f4fc66b48d98b6e1c80fce03 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c7a665b6002f98abb4d48f270ef7127bc2306b5a
commit c7a665b6002f98abb4d48f270ef7127bc2306b5a
Merge: e8d7474 7da1cde
Author: Brad King 
AuthorDate: Mon Feb 13 11:42:03 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 11:42:03 2017 -0500

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-58-g38bfe65

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  38bfe65eba21c697d05e8bed79635fc125cdac17 (commit)
   via  6cbad490c2fdbd9bdc67b406b9f2dcdc21e08ddb (commit)
  from  7da1cde3aedd3f09dffaadbe5815a04aa71d411a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-102-gfb4044b

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  fb4044b6f07df33a146df4e19da65e415899cda7 (commit)
   via  44f3acb202c316bc6a863a1823aaafae486c899a (commit)
  from  c7a665b6002f98abb4d48f270ef7127bc2306b5a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fb4044b6f07df33a146df4e19da65e415899cda7
commit fb4044b6f07df33a146df4e19da65e415899cda7
Merge: c7a665b 44f3acb
Author: Brad King 
AuthorDate: Mon Feb 13 11:45:01 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 11:45:01 2017 -0500

Merge topic 'cmake_provide_include_dir_for_toolkit' into next

44f3acb2 CUDA: Detect the toolkit include directories


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=44f3acb202c316bc6a863a1823aaafae486c899a
commit 44f3acb202c316bc6a863a1823aaafae486c899a
Author: Robert Maynard 
AuthorDate: Wed Feb 8 16:51:18 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 16:08:06 2017 -0500

CUDA: Detect the toolkit include directories

The `nvcc -v` output provides what include directories need to be added
to use the CUDA toolkit from other languages ( C/C++ ).

diff --git a/Help/manual/cmake-variables.7.rst 
b/Help/manual/cmake-variables.7.rst
index 95f780a..38444d1 100644
--- a/Help/manual/cmake-variables.7.rst
+++ b/Help/manual/cmake-variables.7.rst
@@ -353,6 +353,7 @@ Variables for Languages
/variable/CMAKE_CUDA_EXTENSIONS
/variable/CMAKE_CUDA_STANDARD
/variable/CMAKE_CUDA_STANDARD_REQUIRED
+   /variable/CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES
/variable/CMAKE_CXX_COMPILE_FEATURES
/variable/CMAKE_CXX_EXTENSIONS
/variable/CMAKE_CXX_STANDARD
diff --git a/Help/variable/CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES.rst 
b/Help/variable/CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES.rst
new file mode 100644
index 000..768f571
--- /dev/null
+++ b/Help/variable/CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES.rst
@@ -0,0 +1,7 @@
+CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES
+--
+
+When the ``CUDA`` language has been enabled, this provides a
+:ref:`;-list ` of include directories provided
+by the CUDA Toolkit.  The value may be useful for C++ source files
+to include CUDA headers.
diff --git a/Modules/CMakeCUDACompiler.cmake.in 
b/Modules/CMakeCUDACompiler.cmake.in
index 158d12b..f524e5f 100644
--- a/Modules/CMakeCUDACompiler.cmake.in
+++ b/Modules/CMakeCUDACompiler.cmake.in
@@ -16,6 +16,8 @@ set(CMAKE_CUDA_SOURCE_FILE_EXTENSIONS cu)
 set(CMAKE_CUDA_LINKER_PREFERENCE 15)
 set(CMAKE_CUDA_LINKER_PREFERENCE_PROPAGATES 1)
 
+set(CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES 
"@CMAKE_CUDA_TOOLKIT_INCLUDE_DIRECTORIES@")
+
 set(CMAKE_CUDA_HOST_IMPLICIT_LINK_LIBRARIES 
"@CMAKE_CUDA_HOST_IMPLICIT_LINK_LIBRARIES@")
 set(CMAKE_CUDA_HOST_IMPLICIT_LINK_DIRECTORIES 
"@CMAKE_CUDA_HOST_IMPLICIT_LINK_DIRECTORIES@")
 set(CMAKE_CUDA_HOST_IMPLICIT_LINK_FRAMEWORK_DIRECTORIES 
"@CMAKE_CUDA_HOST_IMPLICIT_LINK_FRAMEWORK_DIRECTORIES@")
diff --git a/Modules/CMakeDetermineCUDACompiler.cmake 
b/Modules/CMakeDetermineCUDACompiler.cmake
index bef6d0e..7b6d17b 100644
--- a/Modules/CMakeDetermineCUDACompiler.cmake
+++ b/Modules/CMakeDetermineCUDACompiler.cmake
@@ -84,20 +84,20 @@ endif()
 #the compiler with cuda-fake-ld  and pass too CMAKE_PARSE_IMPLICIT_LINK_INFO
 if(CMAKE_CUDA_COMPILER_ID STREQUAL NVIDIA)
   set(_nvcc_log "")
-  string(REPLACE "\r" "" _nvcc_output "${CMAKE_CUDA_COMPILER_PRODUCED_OUTPUT}")
-  if(_nvcc_output MATCHES "#\\\$ +LIBRARIES= *([^\n]*)\n")
+  string(REPLACE "\r" "" _nvcc_output_orig 
"${CMAKE_CUDA_COMPILER_PRODUCED_OUTPUT}")
+  if(_nvcc_output_orig MATCHES "#\\\$ +LIBRARIES= *([^\n]*)\n")
 set(_nvcc_libraries "${CMAKE_MATCH_1}")
 string(APPEND _nvcc_log "  found 'LIBRARIES=' string: 
[${_nvcc_libraries}]\n")
   else()
 set(_nvcc_libraries "")
-string(REPLACE "\n" "\n" _nvcc_output_log "\n${_nvcc_output}")
+string(REPLACE "\n" "\n" _nvcc_output_log "\n${_nvcc_output_orig}")
 string(APPEND _nvcc_log "  no 'LIBRARIES=' string found in nvcc 
output:${_nvcc_output_log}\n")
   endif()
 
   set(_nvcc_link_line "")
   if(_nvcc_libraries)
 # Remove variable assignments.
-string(REGEX REPLACE "#\\\$ *[^= ]+=[^\n]*\n" "" _nvcc_output 
"${_nvcc_output}")
+string(REGEX REPLACE "#\\\$ *[^= ]+=[^\n]*\n" "" _nvcc_output 
"${_nvcc_output_orig}")
 # Split lines.
 string(REGEX REPLACE "\n+(#\\\$ )?" ";" _nvcc_output "${_nvcc_output}")
 foreach(line IN LISTS _nvcc_output)
@@ -150,6 +150,32 @@ if(CMAKE_CUDA_COMPILER_ID STREQUAL NVIDIA)
 message(FATAL_ERROR "Failed to extract nvcc implicit link line.")
   endif()
 
+  se

[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-45-g0c43793

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  0c4379353fb82e0d5223e82faeaf14f4dcc7a80b (commit)
   via  c3800e54583208ac4a6435884bb8832e72af3183 (commit)
  from  0cab748cf84a844df36623f03c5ed7b8065ceb5a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0c4379353fb82e0d5223e82faeaf14f4dcc7a80b
commit 0c4379353fb82e0d5223e82faeaf14f4dcc7a80b
Merge: 0cab748 c3800e5
Author: Brad King 
AuthorDate: Mon Feb 13 11:41:46 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 11:41:46 2017 -0500

Merge topic 'erase-if'

c3800e54 cmAlgorithms: add cmEraseIf function


---

Summary of changes:
 Source/cmAlgorithms.h  |6 ++
 Source/cmGlobalVisualStudio14Generator.cxx |3 +--
 Source/cmLocalUnixMakefileGenerator3.cxx   |5 +
 Source/cmMakefile.cxx  |   13 ++---
 Source/cmNinjaNormalTargetGenerator.cxx|   18 ++
 5 files changed, 16 insertions(+), 29 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-56-g7da1cde

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  7da1cde3aedd3f09dffaadbe5815a04aa71d411a (commit)
   via  166b3393875e4f6752907b9b06c2518dce0432e9 (commit)
   via  cbe4d5957b526f9a9bb6954d0c6944ad7642bb90 (commit)
   via  8731701cb636317df2691359361562f32adfe759 (commit)
   via  0ae5386aa953d1670074c2f1bfc9a04ddb382684 (commit)
   via  ce19607fed3990b8e828330e77f09061c99aa113 (commit)
   via  008ed80dcf1d03640879b4168f4fba956aa03196 (commit)
   via  c0d7bb8368c3d157d1a2758b620fc726355e554d (commit)
   via  21a125cdbff24efa746249a3b8ccc6296c5f0aff (commit)
   via  eebb2be8b0db17bb5f760e7fa04c020406e6f6eb (commit)
   via  84f3c87b030037646c1110b1e4237f597ad3dd88 (commit)
  from  0c4379353fb82e0d5223e82faeaf14f4dcc7a80b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7da1cde3aedd3f09dffaadbe5815a04aa71d411a
commit 7da1cde3aedd3f09dffaadbe5815a04aa71d411a
Merge: 0c43793 166b339
Author: Brad King 
AuthorDate: Mon Feb 13 11:41:49 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 11:41:49 2017 -0500

Merge topic 'cuda_tests_improve_error_reporting'

166b3393 Tests/Cuda: Select a CUDA device supporting compute 3.0
cbe4d595 Tests/Cuda: Return a non-zero code if errors occurred
8731701c Tests/Cuda: Use memory allocated on the GPU in the kernels
0ae5386a Tests/Cuda: Add missing separable compilation property
ce19607f Tests/Cuda: Fix missing CUDA static library at runtime on macOS
008ed80d Tests/Cuda: Output error messages to std::cerr instead of std::cout
c0d7bb83 Tests/Cuda: Print asynchronous error messages, if any
21a125cd Tests/Cuda: Print error message if mixed_kernel failed
eebb2be8 Tests/Cuda: Add identifiers to error messages
84f3c87b Tests/Cuda: Print error message if an error occurred


---

Summary of changes:
 Tests/Cuda/Complex/CMakeLists.txt  |8 ++
 Tests/Cuda/Complex/dynamic.cu  |   51 ++--
 Tests/Cuda/Complex/file3.cu|   39 ++-
 Tests/Cuda/Complex/main.cpp|   12 ++---
 Tests/Cuda/Complex/mixed.cu|   40 +---
 Tests/Cuda/ObjectLibrary/main.cpp  |8 +++---
 Tests/Cuda/ObjectLibrary/static.cu |4 +--
 7 files changed, 141 insertions(+), 21 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-94-ge8d7474

2017-02-13 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  e8d7474006657657f4fc66b48d98b6e1c80fce03 (commit)
   via  e1b5a54d1da318510445fe1fcc969018e1a6b6dd (commit)
  from  9862605636abde65ca8e651d42b3d706beeaaecc (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e8d7474006657657f4fc66b48d98b6e1c80fce03
commit e8d7474006657657f4fc66b48d98b6e1c80fce03
Merge: 9862605 e1b5a54
Author: Brad King 
AuthorDate: Mon Feb 13 11:12:35 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Mon Feb 13 11:12:35 2017 -0500

Merge topic 'update-kwsys' into next

e1b5a54d Revert topic 'update-kwsys'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e1b5a54d1da318510445fe1fcc969018e1a6b6dd
commit e1b5a54d1da318510445fe1fcc969018e1a6b6dd
Author: Brad King 
AuthorDate: Mon Feb 13 11:11:54 2017 -0500
Commit: Brad King 
CommitDate: Mon Feb 13 11:11:54 2017 -0500

Revert topic 'update-kwsys'

It introduces warnings that need to be fixed upstream first.

diff --git a/Source/kwsys/SystemInformation.cxx 
b/Source/kwsys/SystemInformation.cxx
index fc1a752..e01dcd7 100644
--- a/Source/kwsys/SystemInformation.cxx
+++ b/Source/kwsys/SystemInformation.cxx
@@ -35,13 +35,8 @@
 #include "SystemInformation.hxx.in"
 #endif
 
-#include 
-#include 
-#include 
 #include 
 #include 
-#include 
-#include 
 #include 
 #include 
 #include 
@@ -399,6 +394,7 @@ public:
 bool SupportsMP;
 bool HasMMXPlus;
 bool HasSSEMMX;
+bool SupportsHyperthreading;
 unsigned int LogicalProcessorsPerPhysical;
 int APIC_ID;
 CPUPowerManagement PowerManagement;
@@ -467,9 +463,10 @@ protected:
   unsigned int NumberOfLogicalCPU;
   unsigned int NumberOfPhysicalCPU;
 
-  void CPUCountWindows();// For windows
+  int CPUCount(); // For windows
+  unsigned char LogicalCPUPerPhysicalCPU();
   unsigned char GetAPICId(); // For windows
-  bool IsSMTSupported();
+  bool IsHyperThreadingSupported();
   static LongLong GetCyclesDifference(DELAY_FUNC, unsigned int); // For windows
 
   // For Linux and Cygwin, /proc/cpuinfo formats are slightly different
@@ -1545,7 +1542,7 @@ void SystemInformationImplementation::RunCPUCheck()
 RetrieveProcessorSerialNumber();
   }
 
-  this->CPUCountWindows();
+  this->CPUCount();
 
 #elif defined(__APPLE__)
   this->ParseSysCtl();
@@ -2093,10 +2090,16 @@ bool 
SystemInformationImplementation::RetrieveCPUFeatures()
 
   // Retrieve Intel specific extended features.
   if (this->ChipManufacturer == Intel) {
-bool SupportsSMT =
-  ((cpuinfo[3] & 0x1000) != 0); // Intel specific: SMT --> Bit 28
-
-if ((SupportsSMT) && (this->Features.HasAPIC)) {
+this->Features.ExtendedFeatures.SupportsHyperthreading =
+  ((cpuinfo[3] & 0x1000) !=
+   0); // Intel specific: Hyperthreading --> Bit 28
+this->Features.ExtendedFeatures.LogicalProcessorsPerPhysical =
+  (this->Features.ExtendedFeatures.SupportsHyperthreading)
+  ? ((cpuinfo[1] & 0x00FF) >> 16)
+  : 1;
+
+if ((this->Features.ExtendedFeatures.SupportsHyperthreading) &&
+(this->Features.HasAPIC)) {
   // Retrieve APIC information if there is one present.
   this->Features.ExtendedFeatures.APIC_ID =
 ((cpuinfo[1] & 0xFF00) >> 24);
@@ -3398,7 +3401,7 @@ bool 
SystemInformationImplementation::RetreiveInformationFromCpuInfoFile()
   fclose(fd);
   buffer.resize(fileSize - 2);
   // Number of logical CPUs (combination of multiple processors, multi-core
-  // and SMT)
+  // and hyperthreading)
   size_t pos = buffer.find("processor\t");
   while (pos != buffer.npos) {
 this->NumberOfLogicalCPU++;
@@ -3406,24 +3409,30 @@ bool 
SystemInformationImplementation::RetreiveInformationFromCpuInfoFile()
   }
 
 #ifdef __linux
-  // Count sockets.
-  std::set PhysicalIDs;
+  // Find the largest physical id.
+  int maxId = -1;
   std::string idc = this->ExtractValueFromCpuInfoFile(buffer, "physical id");
   while (this->CurrentPositionInFile != buffer.npos) {
 int id = atoi(idc.c_str());
-PhysicalIDs.insert(id);
+if (id > maxId) {
+  maxId = id;
+}
 idc = this->ExtractValueFromCpuInfoFile(buffer, "physical id",
 this->CurrentPositionInFile + 1);
   }
-  uint64_t NumberOfSockets = PhysicalIDs.size();
-  NumberOfSockets = std::max(NumberOfSockets, (uint64_t)1);
   // Physical ids returned by Linux don't distinguish cores.
   // We want to record the total number of cores in this->NumberOfPhysicalCPU
   // (checking only the first proc)
-  std::string Cores = this->ExtractValueFromCpuInfoFile(buffer, "cp